@@ -3,16 +3,23 @@ from .blacklists import Blacklists
 from .client_grants import ClientGrants
 from .clients import Clients
 from .connections import Connections
+from .custom_domains import CustomDomains
 from .device_credentials import DeviceCredentials
+from .email_templates import EmailTemplates
 from .emails import Emails
+from .grants import Grants
 from .guardian import Guardian
+from .hooks import Hooks
 from .jobs import Jobs
+from .log_streams import LogStreams
 from .logs import Logs
 from .resource_servers import ResourceServers
+from .roles import Roles
 from .rules import Rules
+from .rules_configs import RulesConfigs
 from .stats import Stats
 from .tenants import Tenants
 from .tickets import Tickets
 from .user_blocks import UserBlocks
 from .users import Users
-
+from .users_by_email import UsersByEmail
